About
=====

SymPy Development Team
----------------------

.. literalinclude:: ../../AUTHORS


You can find a brief history of SymPy in the `README <https://github.com/sympy/sympy/blob/master/README.rst>`_.

Financial and Infrastructure Support
------------------------------------

* `Google <http://www.google.com/about/company/>`_: SymPy has received generous
  financial support from Google in various years through the `Google Summer of
  Code <http://g.co/gsoc>`_ program by providing stipends:

  * in 2007 for 5 students (`GSoC 2007 <https://github.com/sympy/sympy/wiki/GSoC-2007-Report>`_)
  * in 2008 for 1 student (`GSoC 2008 <https://github.com/sympy/sympy/wiki/GSoC-2008-report>`_)
  * in 2009 for 5 students (`GSoC 2009 <https://github.com/sympy/sympy/wiki/GSoC-2009-report>`_)
  * in 2010 for 5 students (`GSoC 2010 <https://github.com/sympy/sympy/wiki/GSoC-2010-report>`_)
  * in 2011 for 9 students (`GSoC 2011 <https://github.com/sympy/sympy/wiki/Gsoc-2011-report>`_)
  * in 2012 for 6 students (`GSoC 2012 <https://github.com/sympy/sympy/wiki/Gsoc-2012-report>`_)
  * in 2013 for 7 students (`GSoC 2013 <https://github.com/sympy/sympy/wiki/Gsoc-2013-report>`_)
  * in 2014 for 10 students (`GSoC 2014 <https://github.com/sympy/sympy/wiki/Gsoc-2014-report>`_)
  * in 2015 for 7 students (`GSoC 2015 <https://github.com/sympy/sympy/wiki/Gsoc-2015-report>`_)
  * in 2016 for 9 students (`GSoC 2016 <https://github.com/sympy/sympy/wiki/GSoC-2016-report>`_)

  Of these, we would like to thank these organizations for hosting GSoC students under their
  umbrella organizations:

  * `Python Software Foundation (PSF) <https://www.python.org/psf/>`_ has hosted
    various GSoC students over the years:

    * 3 GSoC 2007 students (Brian, Robert and Jason)
    * 1 GSoC 2008 student (Fredrik)
    * 2 GSoC 2009 students (Freddie and Priit)
    * 4 GSoC 2010 students (Aaron, Christian, Matthew and Øyvind)
    * 6 GSoC 2015 students
    * 1 GSoC 2016 student (James)

  * `Portland State University (PSU) <http://www.pdx.edu/>`_ has hosted following
    GSoC students:

    * 1 student (Chris) in 2007
    * 3 students (Aaron, Dale and Fabian) in 2009
    * 1 student (Addison) in 2010

  * `The Space Telescope Science Institute <http://www.stsci.edu/portal/>`_: STScI hosted 1 GSoC 2007 student (Mateusz)

  * `The Ruby Science Foundation <http://www.sciruby.com/>`_ has hosted following
    GSoC students:

    * 1 student (Abinash) in 2015
    * 1 student (Rajith) in 2016

* Several 13-17 year old pre-university students contributed as part of
  Google's `Code-In
  <http://www.google-melange.com/gci/homepage/google/gci2011>`_ 2011.  (`GCI
  2011 <http://www.google-melange.com/gci/org/google/gci2011/sympy>`_)

* `Simula Research Laboratory <https://www.simula.no/>`_: supports Pearu Peterson work in SymPy/SymPy Core projects

* `GitHub <https://github.com/about>`_ is providing us with development
  and collaboration tools

License
-------

Unless stated otherwise, all files in the SymPy project, SymPy's webpage (and
wiki), all images and all documentation including this User's Guide are licensed
using the new BSD license:

.. literalinclude:: ../../LICENSE
